Crate stdrandom

stdrandom

Random numbers generator using only Rust standard library.

Functions

fast_f32
Fast but lower-entropy f32 in [0, 1)
fast_f64
Fast but lower-entropy f64 in [0, 1)
fast_i8
Generates a non-negative i8 random number using the current thread’s RandomState.
fast_i16
Generates a non-negative i16 random number using the current thread’s RandomState.
fast_i32
Generates a non-negative i32 random number using the current thread’s RandomState.
fast_i64
Generates a non-negative i64 random number using the current thread’s RandomState.
fast_i128
Generates a non-negative i128 random number using two separate instances of RandomState.
fast_isize
Generates a non-negative isize random number using the current thread’s RandomState.
fast_u8
Generates a u8 random number using the current thread’s RandomState.
fast_u16
Generates a u16 random number using the current thread’s RandomState.
fast_u32
Generates a u32 random number using the current thread’s RandomState.
fast_u64
Generates a u64 random number using the current thread’s RandomState.
fast_u128
Generates a u128 random number using the current thread’s RandomStates.
fast_usize
Generates a usize random number using the current thread’s RandomState.
fill_bytes
Fills slice with random bytes using the provided generator function.
fill_numbers
Fills a slice with generated numbers using the provided generator function.
gen_range
Generates random number in specified range using supplied generator.
random_f32
Higher entropy f32 in [0, 1)
random_f64
Higher entropy f64 in [0, 1)
random_i8
Generates a higher entropy random i8 number in a separate thread.
random_i16
Generates a higher entropy random i16 number in a separate thread.
random_i32
Generates a higher entropy random i32 number in a separate thread.
random_i64
Generates a higher entropy random i64 number in a separate thread.
random_i128
Generates a higher entropy random i128 number using two separate threads.
random_isize
Generates a higher entropy random isize number in a separate thread.
random_u8
Generates a higher entropy random u8 number in a separate thread.
random_u16
Generates a higher entropy random u16 number in a separate thread.
random_u32
Generates a higher entropy random u32 number in a separate thread.
random_u64
Generates higher entropy random u64 number in separate thread.
random_u128
Generates a higher entropy random u128 number using two separate threads.