stdrandom
Random numbers generator using only Rust standard library.
Functions
- fast_
f32 - Fast but lower-entropy
f32in[0, 1) - fast_
f64 - Fast but lower-entropy
f64in[0, 1) - fast_i8
- Generates a non-negative
i8random number using the current thread’sRandomState. - fast_
i16 - Generates a non-negative
i16random number using the current thread’sRandomState. - fast_
i32 - Generates a non-negative
i32random number using the current thread’sRandomState. - fast_
i64 - Generates a non-negative
i64random number using the current thread’sRandomState. - fast_
i128 - Generates a non-negative
i128random number using two separate instances ofRandomState. - fast_
isize - Generates a non-negative
isizerandom number using the current thread’sRandomState. - fast_u8
- Generates a
u8random number using the current thread’sRandomState. - fast_
u16 - Generates a
u16random number using the current thread’sRandomState. - fast_
u32 - Generates a
u32random number using the current thread’sRandomState. - fast_
u64 - Generates a
u64random number using the current thread’sRandomState. - fast_
u128 - Generates a
u128random number using the current thread’sRandomStates. - fast_
usize - Generates a
usizerandom number using the current thread’sRandomState. - fill_
bytes - Fills slice with random bytes using the provided generator function.
- fill_
numbers - Fills a slice with generated numbers using the provided generator function.
- gen_
range - Generates random number in specified range using supplied generator.
- random_
f32 - Higher entropy
f32in[0, 1) - random_
f64 - Higher entropy
f64in[0, 1) - random_
i8 - Generates a higher entropy random
i8number in a separate thread. - random_
i16 - Generates a higher entropy random
i16number in a separate thread. - random_
i32 - Generates a higher entropy random
i32number in a separate thread. - random_
i64 - Generates a higher entropy random
i64number in a separate thread. - random_
i128 - Generates a higher entropy random
i128number using two separate threads. - random_
isize - Generates a higher entropy random
isizenumber in a separate thread. - random_
u8 - Generates a higher entropy random
u8number in a separate thread. - random_
u16 - Generates a higher entropy random
u16number in a separate thread. - random_
u32 - Generates a higher entropy random
u32number in a separate thread. - random_
u64 - Generates higher entropy random u64 number in separate thread.
- random_
u128 - Generates a higher entropy random
u128number using two separate threads.