pub fn random_f32() -> f32Expand description
Generates a higher entropy f32 pseudo-random number in the range [0.0, 1.0).
This function achieves higher randomness by leveraging a source like random_u64(),
which is designed to provide better statistical properties and less predictability
by generating values in a separate thread.
It results in numbers with significantly higher entropy compared to fast_f32().
Returns
- A non-negative pseudo-random
f32number within the half-open interval[0.0, 1.0).
Example
let random_value = stdrandom::random_f32();
println!("Generated higher entropy f32: {}", random_value);